<?php

namespace General\Services\Report;

use General\Models\Report\ReportUserBindRecord;
use Exception;
use GuzzleHttp\Client;

/**
 * 数据上报基类
 */
abstract class BaseReport implements ReportInterface
{
    /**
     * 充值用户事件类型
     */
    protected $charge_event_type;
    /**
     * 注册用户事件类型
     */
    protected $register_event_type;
    /**
     * 加桌事件类型
     */
    protected $add_desk_event_type;
    /**
     * 充值用户数据上报地址
     */
    protected $report_url;

    public abstract function getChargeQueryParams(ReportUserBindRecord $user, float $amount): array;

    public abstract function getRegisterQueryParams(ReportUserBindRecord $user): array;

//    public abstract function getAddDeskQueryParams(ReportUserBindRecord $user): array;

    /**
     * 付费上报
     */
    public function reportCharge(ReportUserBindRecord $user, float $amount)
    {
        $query_params = $this->getChargeQueryParams($user, $amount);
        return $this->report($query_params);
    }

    /**
     * 注册上报
     */
    public function reportRegister(ReportUserBindRecord $user)
    {
        $query_params = $this->getRegisterQueryParams($user);
        return $this->report($query_params);
    }

    /**
     * 加卓上报
     * @param ReportUserBindRecord $user
     * @return array
     */
//    public function reportAddDesk(ReportUserBindRecord $user)
//    {
//        $query_params = $this->getAddDeskQueryParams($user);
//        return $this->report($query_params);
//    }

    public function report(array $query_params)
    {
        $result = false;
        $content = '';
        try {
            $url = $this->report_url . '?' . http_build_query($query_params);
            $client = new Client(['timeout' => 4]);
            $response = $client->get($url);
            $content = $response->getBody()->getContents();
            $status_code = $response->getStatusCode();
            if ($status_code == 200) {
                $result = true;
            } else {
                $result = false;
            }
            myLog('report')->info('report_param:'.json_encode($query_params).' response:'.json_encode($response).' url:'.$url);
            
        } catch (Exception $e) {
            myLog('report')->error($url);
            myLog('report')->error($e->getMessage());
        } finally {
            return [
                'result' => $result,
                'content' => $content,
            ];
        }
    }
}
